@@ -17,10 +17,6 @@ use WWW::AUR                qw( _path_params _useragent );
 # CONSTANTS
 #-----------------------------------------------------------------------------
 
-my $MAINTAINER_MATCH = qr{ <span [ ] class='f3'>
-                           Maintainer: \s+ ( [^<]+ )
-                           </span> }xms;
-
 #---CONSTRUCTOR---
 sub new
 {
@@ -59,8 +55,16 @@ sub _def_info_accessor
     };
 }
 
-for ( qw{ id name version desc category locationid url urlpath
-          license votes outdated } ) { _def_info_accessor( $_ ); }
+for ( qw{ id name version desc category url urlpath
+          license votes outdated ctime mtime } ) {
+    _def_info_accessor( $_ );
+}
+
+sub maintainer_name
+{
+    my ($self) = @_;
+    return $self->{'info'}{'maintainer'}; # might be undef for orphan
+}
 
 #---PUBLIC METHOD---
 # Returns a copy of the package info as a hash...
@@ -135,30 +139,6 @@ sub download
     return $pkgpath;
 }
 
-
-#---PUBLIC METHOD---
-# Purpose: Scrape the package webpage to get the maintainer's name
-sub maintainer_name
-{
-    my ($self) = @_;
-
-    my $uri  = pkg_uri( ID => $self->id );
-    my $ua   = _useragent();
-    my $resp = $ua->get( $uri );
-
-    Carp::croak sprintf q{Failed to load webpage for the }
-        . q{"%s" package:\n%s}, $self->name, $resp->status_line
-        unless $resp->is_success;
-
-    my ($username) = $resp->content() =~ /$MAINTAINER_MATCH/xms;
-    Carp::croak qq{Failed to scrape package webpage for maintainer}
-        unless $username;
-
-    # Orphaned packages don't have a maintainer...
-    return undef if $username eq 'None';
-    return $username;
-}
-
 #---PUBLIC METHOD---
 # Purpose: Returns an object representing the package maintainer.
 sub maintainer
